/*********************************************************************************

Copyright(c) 2014-2016 Analog Devices, Inc. All Rights Reserved.

This software is proprietary and confidential.  By using this software you agree
to the terms of the associated Analog Devices License Agreement.

*********************************************************************************/

/*
 * Configure the clock output on the Si5356A (clock generator).  The Si5356A device is
 * located on the ADSP-SC573/ADSP-SC589 EZ-Kit.  TWI communication is used to configure the device.
 *
 */

#include <stdio.h>

#include <drivers/twi/adi_twi.h>
#include <services/pwr/adi_pwr.h>
#include "configClocks.h"

/* Silicon Labs ClockBuilder register configuration */
//#include "adau1962a_10MHz.h"  /* audio clock */
#include "Bose_22_5792MHz.h"  /* audio clock */

static ADI_TWI_HANDLE hDevice;

static bool bError = false;

static void CheckResult(ADI_TWI_RESULT result, char *message);
static void ReadRegister(uint8_t reg, uint8_t *value);

static uint8_t devBuffer[BUFFER_SIZE];

/*
 * Report error if result code is not success
 */
static void CheckResult(ADI_TWI_RESULT result, char *message)
{
	if (result != ADI_TWI_SUCCESS)
	{
		printf("%s failed\n", message);
		bError = true;
	}
}

/*
 * Read a Si5356A register value
 */
static void ReadRegister(uint8_t reg, uint8_t *value)
{
	ADI_TWI_RESULT result;

	/* write register address */
	devBuffer[0] = reg;
	result = adi_twi_Write(hDevice, devBuffer, 1u, true);
	CheckResult(result, "adi_twi_Write");

	/* read register value */
	result = adi_twi_Read(hDevice, value, 1u, false);
	CheckResult(result, "adi_twi_Read");
}

/*
 * configClocks
 */
void configClocks (void)
{
	ADI_TWI_RESULT result;
	ADI_PWR_RESULT pwrResult;
	uint8_t value;
	uint8_t mask;
	uint32_t nReg;
	uint8_t deviceMemory[ADI_TWI_MEMORY_SIZE];

	/* clear error flag */
	bError = false;

	/* Set CGU clock select register to CLKO2/4 (ARM core) */
	pwrResult = adi_pwr_SetClkOutSelectRegister(CGU_DEV, ADI_PWR_CLKOUT_CLKO2);

	result = adi_twi_Open(TWIDEVNUM, ADI_TWI_MASTER, &deviceMemory[0],
			ADI_TWI_MEMORY_SIZE, &hDevice);
	CheckResult(result, "adi_twi_Open");

	result = adi_twi_SetPrescale(hDevice, PRESCALEVALUE);
	CheckResult(result, "adi_twi_Prescale");

	result = adi_twi_SetBitRate(hDevice, BITRATE);
	CheckResult(result, "adi_twi_SetBitRate");

	result = adi_twi_SetDutyCycle(hDevice, DUTYCYCLE);
	CheckResult(result, "adi_twi_SetDutyCycle");

	/* set Si5356A slave address */
	result = adi_twi_SetHardwareAddress(hDevice, TARGETADDR);
	CheckResult(result, "adi_twi_SetHardwareAddress");

	/* write the ClockBuilder register configuration */
	for (nReg=0; nReg<NUM_REGS_MAX; nReg++)
	{
		mask = Reg_Store[nReg].Reg_Mask;
		if (mask != 0x00)
		{
			/* read the register */
			value = 0u;
			ReadRegister(Reg_Store[nReg].Reg_Addr, &value);

			/* apply mask */
			value &= ~mask;

			/* modify value */
			value |= (Reg_Store[nReg].Reg_Val & mask);

			/* write value */
			devBuffer[0] = Reg_Store[nReg].Reg_Addr;
			devBuffer[1] = value;
			result = adi_twi_Write(hDevice, devBuffer, 2u, false);
			CheckResult(result, "adi_twi_Write");
		}
	}

	if (!bError)
	{
		/* IF (TWI Device is already open) */
		if (hDevice != NULL)
		{
			/* Close TWI Device */
			adi_twi_Close(hDevice);
			/* Clear the TWI Device handle */
			hDevice = NULL;
		}
		printf("All done\n");
	}
	else
	{
		printf("Example failed.\n");
	}
}
